# Python Utilities

General utilities for Python

- Business indicator
- Print styling
- General utility exceptions
- Debugging
- General utility functions
- Date time formatting
- Socket utilities

For even more general tools see Pything/Warg @Github @Pypi Once mature enough, modules here may migrate to warg